@@ -5,18 +5,20 @@
 #' @param main_es a logical variable indicating whether a main effect size should be selected when overlapping data are present. See details.
 #' @param split_adjusted a logical value indicating whether crude and adjusted effect sizes should be presented separately. See details.
 #' @param format_adjusted presentation format of the adjusted effect sizes. See details.
-#' @param hierarchy a character string indicating the hierarchy in the information to be prioritized for the effect size calculations (see details). See details.
+#' @param hierarchy a character string indicating the hierarchy in the information to be prioritized for the effect size calculations. See details.
+#' @param selection_auto a character string giving details on the best "auto" hierarchy to use (only useful when \code{hierarchy="auto"} and \code{measure= "d", "g" or "md"}). See details.
 #' @param es_selected the method used to select the main effect size when several information allows to estimate an effect size for the same association/comparison. Must be either "minimum" (the smallest effect size will be selected), "maximum" (the largest effect size will be selected) or "hierarchy" (the effect size computed from the information specified highest in the hierarchy will be selected). See details.
+#' @param table_2x2_to_cor formula used to obtain a correlation coefficient from the contingency table. For now only 'tetrachoric' is available.
 #' @param rr_to_or formula used to convert the \code{rr} value into an odds ratio.
 #' @param or_to_rr formula used to convert the \code{or} value into a risk ratio.
 #' @param or_to_cor formula used to convert the \code{or} value into a correlation coefficient.
-#' @param table_2x2_to_cor formula used to obtain a correlation coefficient from the contingency table.
 #' @param pre_post_to_smd formula used to obtain a SMD from pre/post means and SD of two independent groups.
 #' @param r_pre_post pre-post correlation across the two groups (use this argument only if the precise correlation in each group is unknown)
 #' @param smd_to_cor formula used to convert the \code{cohen_d} value into a coefficient correlation.
 #' @param cor_to_smd formula used to convert a correlation coefficient value into a SMD.
 #' @param yates_chisq a logical value indicating whether the Chi square has been performed using Yate's correction for continuity.
 #' @param unit_type the type of unit for the \code{unit_increase_iv} argument. Must be either "sd" or "value" (see \code{\link{es_from_pearson_r}}).
+#' @param max_asymmetry A percentage indicating the tolerance before detecting asymmetry in the 95% CI bounds.
 #' @param verbose a logical variable indicating whether text outputs and messages should be generated. We recommend turning this option to FALSE only after having carefully read all the generated messages.
 #'
 #' @details
@@ -55,21 +57,120 @@
 #' If you choose to estimate one main effect size (i.e., by setting \code{main_es = TRUE}),
 #' you have several options to select this main effect size.
 #' If you set:
-#' - \code{es_selected = "hierarchy"}: the main effect size will be selected by prioritizing
+#' - \code{es_selected = "auto"}: the main effect size will be **automatically** selected, by prioritizing
 #' specific types of input data over other (see next section "Hierarchy").
-#' - \code{es_selected = "minimum"}: the main effect size will be selected by selecting
+#' - \code{es_selected = "hierarchy"}: the main effect size will be selected, by prioritizing
+#' specific types of input data over other (see next section "Hierarchy").
+#' - \code{es_selected = "minimum"}: the main effect size will be selected, by selecting
 #' the lowest effect size available.
-#' - \code{es_selected = "maximum"}: the main effect size will be selected by selecting
+#' - \code{es_selected = "maximum"}: the main effect size will be selected, by selecting
 #' the highest effect size available.
 #'
 #' ## Hierarchy
 #' More than 70 different combinations of input data can be used to estimate an effect size.
 #' You can retrieve the effect size measures estimated by each combination of input data
-#' in the \code{\link{see_input_data}()} function.
+#' in the \code{\link{see_input_data}()} function and online \code{https://metaconvert.org/input.html}.
 #'
-#' In the hierarchy argument, each type of input data should be separated by the symbol ">".
+#' You have two options to use a hierarchy in the types of input data.
+#' * an automatic way (\code{es_selected = "auto"})
+#' * an manual way (\code{es_selected = "hierarchy"})
+#'
+#' ### Automatic
+#' If you select an automatic hierarchy, here are the types of input data that will be prioritized.
+#'
+#' #### Crude SMD or MD (\code{measure=c("d", "g", "md")} and \code{selection_auto="crude"})
+#' 1. User's input effect size value
+#' 2. SMD value
+#' 3. Means at post-test
+#' 4. ANOVA/Student's t-test/point biserial correlation statistics
+#' 5. Linear regression estimates
+#' 6. Mean difference values
+#' 7. Quartiles/median/maximum values
+#' 8. Post-test means extracted from a plot
+#' 9. Pre-test+post-test means or mean change
+#' 10. Paired ANOVA/t-test statistics
+#' 11. Odds ratio value
+#' 12. Contingency table
+#' 13. Correlation coefficients
+#' 14. Phi/chi-square value
+#'
+#' #### Paired SMD or MD (\code{measure=c("d", "g", "md")} and \code{selection_auto="paired"})
+#' 1. User's input effect size value
+#' 2. Paired SMD value
+#' 3. Pre-test+post-test means or mean change
+#' 4. Paired ANOVA/t-test statistics
+#' 5. Means at post-test
+#' 6. ANOVA/Student's t-test/point biserial correlation
+#' 7. Linear regression estimates
+#' 8. Mean difference values
+#' 9. Quartiles/median/maximum values
+#' 10. Odds ratio value
+#' 11. Contingency table
+#' 12. Correlation coefficients
+#' 13. Phi/chi-square value
+#'
+#' #### Adjusted SMD or MD (\code{measure=c("d", "g", "md")} and \code{selection_auto="adjusted"})
+#' 1. User's input adjusted effect size value
+#' 2. Adjusted SMD value
+#' 3. Estimated marginal means from ANCOVA
+#' 4. F- or t-test value from ANCOVA
+#' 5. Adjusted mean difference from ANCOVA
+#' 6. Estimated marginal means from ANCOVA extracted from a plot
+#'
+#' #### Odds Ratio (\code{measure=c("or")})
+#' 1.	User's input effect size value
+#' 2.	Odds ratio value
+#' 3.	Contingency table
+#' 4.	Risk ratio values
+#' 5.	Phi/chi-square value
+#' 6.	Correlation coefficients
+#' 7.	(Then hierarchy as for "d" or "g" option crude)
+#'
+#' #### Risk Ratio (\code{measure=c("rr")})
+#' 1.	User's input effect size value
+#' 2.	Risk ratio values
+#' 3.	Contingency table
+#' 4.	Odds ratio values
+#' 5.	Phi/chi-square value
+#'
+#' #### Incidence rate ratio (\code{measure=c("irr")})
+#' 1.	User's input effect size value
+#' 2.	Number of cases and time of disease free observation time
+#'
+#' #### Correlation (\code{measure=c("r", "z")})
+#' 1. User's input effect size value
+#' 2. Correlation coefficients
+#' 3. Contingency table
+#' 4. Odds ratio value
+#' 5. Phi/chi-square value
+#' 6. SMD value
+#' 7. Means at post-test
+#' 8. ANOVA/Student's t-test/point biserial correlation
+#' 9. Linear regression estimates
+#' 10. Mean difference values
+#' 11 Quartiles/median/maximum values
+#' 12. Post-test means extracted from a plot
+#' 13. Pre-test+post-test means or mean change
+#' 14. Paired ANOVA/t-test
+#'
+#' #### Variability ratios (\code{measure=c("vr", "cvr")})
+#' 1.	User's input effect size value
+#' 2. means/variability indices at post-test
+#' 3. means/variability indices at post-test extracted from a plot
+#'
+#' #### Number needed to treat (\code{measure=c("nnt")})
+#' 1.	User's input effect size value
+#' 2.	Contingency table
+#' 3.	Odds ratio values
+#' 4.	Risk ratio values
+#' 5.	Phi/chi-square value
+#'
+#' ### Manual
+#'
+#' If you select a manual hierarchy, you can specify the order in which you want to
+#' use each type of input data.
 #' You can prioritize some types of input data by placing them at the begining of the
-#' hierarchy argument.
+#' hierarchy argument, and you must separate all input data with a ">" separator.
 #' For example, if you set:
 #' - \code{hierarchy = "means_sd > means_se > student_t"}, the convert_df function will prioritize
 #' the means + SD, then the means + SE, then the Student's t-test to estimate the main effect
@@ -121,23 +222,27 @@
 convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr",
                                       "nnt", "r", "z", "logvr", "logcvr"),
                        main_es = TRUE,
-                       es_selected = c("hierarchy", "minimum", "maximum"),
+                       es_selected = c("auto", "hierarchy", "minimum", "maximum"),
+                       selection_auto = c("crude", "paired", "adjusted"),
                        split_adjusted = TRUE,
                        format_adjusted = c("wide", "long"),
                        verbose = TRUE,
+                       max_asymmetry = 10,
                        hierarchy = "means_sd > means_se > means_ci",
+                       table_2x2_to_cor = "tetrachoric",
                        rr_to_or = "metaumbrella",
                        or_to_rr = "metaumbrella_cases",
                        or_to_cor = "bonett",
-                       table_2x2_to_cor = "lipsey",
                        smd_to_cor = "viechtbauer",
                        pre_post_to_smd = "bonett",
                        r_pre_post = 0.5,
                        cor_to_smd = "viechtbauer",
                        unit_type = "raw_scale",
                        yates_chisq = FALSE) {
+  # @param table_2x2_to_cor formula used to obtain a correlation coefficient from the contingency table.
+  # table_2x2_to_cor = "tetrachoric",
 
-  # x = dat
+  # x = df.haza
   # measure = "d";
   # main_es = TRUE;
   # es_selected = "hierarchy";
@@ -156,8 +261,10 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
   # cor_to_smd = "viechtbauer";
   # unit_type = "raw_scale";
   # yates_chisq = FALSE
+  # selection_auto = c("crude", "paired", "adjusted")
   measure = measure[1]
   es_selected = es_selected[1]
+  selection_auto = selection_auto[1]
   format_adjusted = format_adjusted[1]
 
   x <- .check_data(x, split_adjusted = split_adjusted,
@@ -168,7 +275,7 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
   for (i in c("rr_to_or",
               "or_to_rr",
               "or_to_cor",
-              "table_2x2_to_cor",
+              # "table_2x2_to_cor",
               "smd_to_cor",
               "pre_post_to_smd",
               "cor_to_smd",
@@ -194,7 +301,7 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     stop(paste0("'", split_adjusted, "' not in tolerated values for the 'split_adjusted' argument. Should be a logical value (TRUE/FALSE)"))
   } else if (!format_adjusted %in% c("wide", "long")) {
     stop(paste0("'", format_adjusted, "' not in tolerated values for the 'format_adjusted' argument. Should be either 'long' or 'wide'."))
-  } else if (!es_selected %in% c("minimum", "maximum", "hierarchy")) {
+  } else if (!es_selected %in% c("auto", "minimum", "maximum", "hierarchy")) {
     stop(paste0("'", es_selected, "' not in tolerated values for the 'es_selected' argument. Possible inputs are: 'minimum', 'maximum', 'hierarchy'"))
   } else if (!main_es %in% c(TRUE, FALSE)) {
     stop(paste0("'", main_es, "' not in tolerated values for the 'main_es' argument. Should be a logical value (TRUE/FALSE)"))
@@ -248,7 +355,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     baseline_risk = baseline_risk, n_exp = n_exp, n_nexp = n_nexp,
     logor_ci_lo = logor_ci_lo, logor_ci_up = logor_ci_up,
     n_cases = n_cases, n_controls = n_controls, n_sample = n_sample,
-    or_to_rr = or_to_rr, or_to_cor = or_to_cor, reverse_or = reverse_or
+    or_to_rr = or_to_rr, or_to_cor = or_to_cor, reverse_or = reverse_or,
+    max_asymmetry = max_asymmetry
   ))
   es_odds_ratio_pval <- with(x, es_from_or_pval(
     or = or, logor = logor, or_pval = or_pval, small_margin_prop = small_margin_prop,
@@ -295,7 +403,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
       n_exp = n_exp, n_nexp = n_nexp,
       mean_exp = mean_exp, mean_ci_lo_exp = mean_ci_lo_exp, mean_ci_up_exp = mean_ci_up_exp,
       mean_nexp = mean_nexp, mean_ci_lo_nexp = mean_ci_lo_nexp, mean_ci_up_nexp = mean_ci_up_nexp,
-      smd_to_cor = smd_to_cor, reverse_means = reverse_means
+      smd_to_cor = smd_to_cor, reverse_means = reverse_means,
+      max_asymmetry = max_asymmetry
     )
   )
   es_means_sd_pooled <- with(
@@ -360,7 +469,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
       r_pre_post_exp = r_pre_post_exp, r_pre_post_nexp = r_pre_post_nexp,
 
       smd_to_cor = smd_to_cor, reverse_means_pre_post = reverse_means_pre_post,
-      pre_post_to_smd = pre_post_to_smd
+      pre_post_to_smd = pre_post_to_smd,
+      max_asymmetry = max_asymmetry
     )
   )
 
@@ -388,7 +498,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     mean_change_ci_lo_nexp = mean_change_ci_lo_nexp, mean_change_ci_up_nexp = mean_change_ci_up_nexp,
     r_pre_post_exp = r_pre_post_exp, r_pre_post_nexp = r_pre_post_nexp,
 
-    smd_to_cor = smd_to_cor, reverse_mean_change = reverse_mean_change
+    smd_to_cor = smd_to_cor, reverse_mean_change = reverse_mean_change,
+    max_asymmetry = max_asymmetry
   ))
   es_mean_change_pval <- with(x, es_from_mean_change_pval(
     n_exp = n_exp, n_nexp = n_nexp,
@@ -468,7 +579,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
   ))
   es_md_ci <- with(x, es_from_md_ci(
     md = md, md_ci_lo = md_ci_lo, md_ci_up = md_ci_up, n_exp = n_exp, n_nexp = n_nexp,
-    smd_to_cor = smd_to_cor, reverse_md = reverse_md
+    smd_to_cor = smd_to_cor, reverse_md = reverse_md,
+    max_asymmetry = max_asymmetry
   ))
   es_md_pval <- with(x, es_from_md_pval(
     md = md, md_pval = md_pval, n_exp = n_exp, n_nexp = n_nexp,
@@ -510,7 +622,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     ancova_mean_ci_lo_exp = ancova_mean_ci_lo_exp, ancova_mean_ci_up_exp = ancova_mean_ci_up_exp,
     ancova_mean_ci_lo_nexp = ancova_mean_ci_lo_nexp, ancova_mean_ci_up_nexp = ancova_mean_ci_up_nexp,
     cov_outcome_r = cov_outcome_r, n_cov_ancova = n_cov_ancova, n_exp = n_exp, n_nexp = n_nexp,
-    smd_to_cor = smd_to_cor, reverse_ancova_means = reverse_ancova_means
+    smd_to_cor = smd_to_cor, reverse_ancova_means = reverse_ancova_means,
+    max_asymmetry = max_asymmetry
   ))
   es_ancova_means_sd_pooled_adj <- with(x, es_from_ancova_means_sd_pooled_adj(
     ancova_mean_exp = ancova_mean_exp, ancova_mean_nexp = ancova_mean_nexp,
@@ -552,7 +665,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
          cov_outcome_r = cov_outcome_r, n_cov_ancova = n_cov_ancova,
          n_exp = n_exp, n_nexp = n_nexp,
          smd_to_cor = smd_to_cor,
-         reverse_ancova_md = reverse_ancova_md))
+         reverse_ancova_md = reverse_ancova_md,
+         max_asymmetry = max_asymmetry))
   es_ancova_md_pval <- with(x, es_from_ancova_md_pval(
         ancova_md = ancova_md,
         ancova_md_pval = ancova_md_pval,
@@ -617,15 +731,18 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
   es_2x2 <- with(x, es_from_2x2(
     n_cases_exp = n_cases_exp, n_cases_nexp = n_cases_nexp,
     n_controls_exp = n_controls_exp, n_controls_nexp = n_controls_nexp,
-    table_2x2_to_cor = table_2x2_to_cor, reverse_2x2 = reverse_2x2
+    # table_2x2_to_cor = table_2x2_to_cor,
+    reverse_2x2 = reverse_2x2
   ))
   es_2x2_sum <- with(x, es_from_2x2_sum(
     n_cases_exp = n_cases_exp, n_cases_nexp = n_cases_nexp, n_exp = n_exp, n_nexp = n_nexp,
-    table_2x2_to_cor = table_2x2_to_cor, reverse_2x2 = reverse_2x2
+    # table_2x2_to_cor = table_2x2_to_cor,
+    reverse_2x2 = reverse_2x2
   ))
   es_prop <- with(x, es_from_2x2_prop(
     prop_cases_exp = prop_cases_exp, prop_cases_nexp = prop_cases_nexp, n_exp = n_exp, n_nexp = n_nexp,
-    table_2x2_to_cor = table_2x2_to_cor, reverse_prop = reverse_prop
+    # table_2x2_to_cor = table_2x2_to_cor,
+    reverse_prop = reverse_prop
   ))
 
   # RR --------------------------------------------------------
@@ -639,7 +756,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     rr = rr, logrr = logrr,
     baseline_risk = baseline_risk, n_exp = n_exp, n_nexp = n_nexp,
     rr_ci_lo = rr_ci_lo, logrr_ci_lo = logrr_ci_lo, rr_ci_up = rr_ci_up, logrr_ci_up = logrr_ci_up, n_cases = n_cases, n_controls = n_controls,
-    rr_to_or = rr_to_or, smd_to_cor = smd_to_cor, reverse_rr = reverse_rr
+    rr_to_or = rr_to_or, smd_to_cor = smd_to_cor, reverse_rr = reverse_rr,
+    max_asymmetry = max_asymmetry
   ))
   es_rr_pval <- with(x, es_from_rr_pval(
     rr = rr, logrr = logrr, rr_pval = rr_pval,
@@ -665,7 +783,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     user_es_crude = x$user_es_crude,
     user_se_crude = x$user_se_crude,
     user_ci_lo_crude = x$user_ci_lo_crude,
-    user_ci_up_crude = x$user_ci_up_crude
+    user_ci_up_crude = x$user_ci_up_crude,
+    max_asymmetry = max_asymmetry
   )
   es_user_adj <- es_from_user_adj(
     user_es_measure_adj = x$user_es_measure_adj,
@@ -673,7 +792,8 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     user_se_adj = x$user_se_adj,
     user_ci_lo_adj = x$user_ci_lo_adj,
     user_ci_up_adj = x$user_ci_up_adj,
-    measure = measure
+    measure = measure,
+    max_asymmetry = max_asymmetry
   )
   # survival
   es_cases_time <- with(x, es_from_cases_time(
@@ -702,74 +822,216 @@ convert_df <- function(x, measure = c("d", "g", "md", "logor", "logrr", "logirr"
     reverse_means_variability = reverse_means_variability
   ))
   # ========================================= STEP 2. SYNTHESIS OF CALCULATIONS =========================================== #
-  res <- list(
-    es_user_crude = es_user_crude, es_user_adj = es_user_adj,
-    # ES value
-    es_cohen_d = es_cohen_d, es_cohen_d_adj = es_cohen_d_adj,
-    es_hedges_g = es_hedges_g,
-    es_odds_ratio = es_odds_ratio, es_odds_ratio_se = es_odds_ratio_se,
-    es_odds_ratio_ci = es_odds_ratio_ci, es_odds_ratio_pval = es_odds_ratio_pval,
-    es_pearson_r = es_pearson_r, es_fisher_z = es_fisher_z,
-    # raw means + (SD SD_pooled SE CI)
-    es_means_sd_raw = es_means_sd_raw, es_means_sd_pooled = es_means_sd_pooled,
-    es_means_se_raw = es_means_se_raw, es_means_ci_raw = es_means_ci_raw,
-    # paired MC
-    es_means_change_sd = es_means_change_sd,
-    es_mean_change_se = es_mean_change_se,
-    es_mean_change_ci = es_mean_change_ci,
-    es_mean_change_pval = es_mean_change_pval,
-    # paired means
-    es_means_sd_pre_post = es_means_sd_pre_post,
-    es_means_se_pre_post = es_means_se_pre_post,
-    es_means_ci_pre_post = es_means_ci_pre_post,
-    # paired stats
-    es_paired_t = es_paired_t, es_paired_t_pval = es_paired_t_pval,
-    es_paired_f = es_paired_f, es_paired_f_pval = es_paired_f_pval,
-    # t, z-score or F value
-    es_t_student = es_t_student, es_t_student_pval = es_t_student_pval, es_anova_f = es_anova_f,
-    es_anova_f_pval = es_anova_f_pval, es_etasq = es_etasq,
-    # mean difference
-    es_md_sd = es_md_sd, es_md_se = es_md_se, es_md_ci = es_md_ci, es_md_pval = es_md_pval,
-    # raw medians + quarts/minmax
-    es_med_quarts = es_med_quarts, es_med_min_max = es_med_min_max, es_med_min_max_quarts = es_med_min_max_quarts,
-    # PLOT
-    es_plot_means_raw = es_plot_means_raw,
-    # ANCOVA means
-    es_ancova_means_sd = es_ancova_means_sd,
-    es_ancova_means_se = es_ancova_means_se,
-    es_ancova_means_ci = es_ancova_means_ci,
-    es_ancova_means_sd_pooled = es_ancova_means_sd_pooled,
-    es_ancova_means_sd_pooled_adj = es_ancova_means_sd_pooled_adj,
-    # ANCOVA stats
-    es_ancova_t = es_ancova_t, es_ancova_f = es_ancova_f,
-    es_ancova_t_pval = es_ancova_t_pval,
-    es_ancova_f_pval = es_ancova_f_pval,
-    es_etasq_adj = es_etasq_adj,
-    es_plot_ancova_means = es_plot_ancova_means,
-    # ANCOVA MD
-    es_ancova_md_sd = es_ancova_md_sd,
-    es_ancova_md_se = es_ancova_md_se,
-    es_ancova_md_ci = es_ancova_md_ci,
-    es_ancova_md_pval = es_ancova_md_pval,
-    # CHI-SQ + PHI
-    es_chisq = es_chisq,
-    es_chisq_pval = es_chisq_pval,
-    es_phi = es_phi, # es_phi_pval = es_phi_pval,
-    # COR-PB
-    es_r_point_bis = es_r_point_bis, es_r_point_bis_pval = es_r_point_bis_pval,
-    # 2x2, PROP
-    es_2x2 = es_2x2, es_2x2_sum = es_2x2_sum, es_prop = es_prop,
-    # RR
-    es_rr_se = es_rr_se, es_rr_ci = es_rr_ci, es_rr_pval = es_rr_pval,
-    # regression
-    es_std_beta = es_std_beta, es_unstd_beta = es_unstd_beta,
-    # survival
-    es_cases_time = es_cases_time,
-    # variability
-    var_means_sd = var_means_sd, var_means_se = var_means_se, var_means_ci = var_means_ci
-    # var_means_change = var_means_change
-  )
 
+  smd_list_L1 = list(es_cohen_d = es_cohen_d,
+                es_hedges_g = es_hedges_g)
+  or_list_L2 = list(es_odds_ratio = es_odds_ratio,
+                 es_odds_ratio_se = es_odds_ratio_se,
+                 es_odds_ratio_ci = es_odds_ratio_ci,
+                 es_odds_ratio_pval = es_odds_ratio_pval)
+  rr_list_L3 = list(es_rr_se = es_rr_se,
+                     es_rr_ci = es_rr_ci,
+                     es_rr_pval = es_rr_pval)
+  cor_list_L4 = list(es_pearson_r = es_pearson_r,
+                  es_fisher_z = es_fisher_z)
+  irr_list_L5 = list(es_cases_time = es_cases_time)
+
+  var_list_L6 = list(var_means_sd = var_means_sd,
+                     var_means_se = var_means_se,
+                     var_means_ci = var_means_ci)
+
+  contigency_list_L7 = list(es_2x2 = es_2x2,
+                         es_2x2_sum = es_2x2_sum,
+                         es_prop = es_prop)
+
+  phi_chisq_list_L8 = list(es_chisq = es_chisq,
+                           es_phi = es_phi,
+                           es_chisq_pval = es_chisq_pval)
+
+  means_post_list_L9 = list(es_means_sd_raw = es_means_sd_raw,
+                         es_means_sd_pooled = es_means_sd_pooled,
+                         es_means_se_raw = es_means_se_raw,
+                         es_means_ci_raw = es_means_ci_raw)
+  md_post_list_L10 = list(es_md_sd = es_md_sd,
+                      es_md_se = es_md_se,
+                      es_md_ci = es_md_ci,
+                      es_md_pval = es_md_pval)
+  anova_list_L11 = list(es_t_student = es_t_student,
+                    es_anova_f = es_anova_f,
+                    es_r_point_bis = es_r_point_bis,
+                    es_t_student_pval = es_t_student_pval,
+                    es_anova_f_pval = es_anova_f_pval,
+                    es_r_point_bis_pval = es_r_point_bis_pval,
+                    es_etasq = es_etasq)
+  medians_list_L12 = list(es_med_quarts = es_med_quarts,
+                      es_med_min_max = es_med_min_max,
+                      es_med_min_max_quarts = es_med_min_max_quarts)
+  regression_list_L13 = list(es_std_beta = es_std_beta,
+                           es_unstd_beta = es_unstd_beta)
+
+  md_paired_list_L14 = list(es_means_change_sd = es_means_change_sd,
+                   es_mean_change_se = es_mean_change_se,
+                   es_mean_change_ci = es_mean_change_ci,
+                   es_mean_change_pval = es_mean_change_pval)
+  means_paired_list_L15 = list(es_means_sd_pre_post = es_means_sd_pre_post,
+                           es_means_se_pre_post = es_means_se_pre_post,
+                           es_means_ci_pre_post = es_means_ci_pre_post)
+  anova_paired_list_L16 = list(es_paired_t = es_paired_t,
+                           es_paired_t_pval = es_paired_t_pval,
+                           es_paired_f = es_paired_f,
+                           es_paired_f_pval = es_paired_f_pval)
+
+  es_cohen_d_adj_L17 = list(es_cohen_d_adj = es_cohen_d_adj)
+  ancova_adjusted_list_L18 = list(es_ancova_t = es_ancova_t,
+                                  es_ancova_f = es_ancova_f,
+                                  es_ancova_t_pval = es_ancova_t_pval,
+                                  es_ancova_f_pval = es_ancova_f_pval,
+                                  es_etasq_adj = es_etasq_adj)
+  means_adjusted_list_L19 = list(es_ancova_means_sd = es_ancova_means_sd,
+                             es_ancova_means_sd_pooled = es_ancova_means_sd_pooled,
+                             es_ancova_means_se = es_ancova_means_se,
+                             es_ancova_means_ci = es_ancova_means_ci,
+                             es_ancova_means_sd_pooled_adj = es_ancova_means_sd_pooled_adj)
+
+  md_adjusted_list_L20 = list(es_ancova_md_sd = es_ancova_md_sd,
+                              es_ancova_md_se = es_ancova_md_se,
+                              es_ancova_md_ci = es_ancova_md_ci,
+                              es_ancova_md_pval = es_ancova_md_pval)
+
+
+  plot_raw_L21 = list(es_plot_means_raw)
+  plot_adjusted_L22 = list(es_plot_ancova_means)
+  user_raw_L23 = list(es_user_crude)
+  es_user_adj_L24 = list(es_user_adj)
+
+  USER_crude = user_raw_L23
+  USER_adjusted = es_user_adj_L24
+
+  SMD_post = c(smd_list_L1, means_post_list_L9,
+               anova_list_L11, regression_list_L13, md_post_list_L10,
+               medians_list_L12, plot_raw_L21)
+
+  SMD_paired = c(means_paired_list_L15, anova_paired_list_L16, md_paired_list_L14)
+
+  SMD_adjusted = c(es_cohen_d_adj_L17, means_adjusted_list_L19, ancova_adjusted_list_L18,
+                   md_adjusted_list_L20,
+                   plot_adjusted_L22)
+
+  OR = c(or_list_L2)
+
+  CONT = contigency_list_L7
+
+  RR = rr_list_L3
+
+  PHI = phi_chisq_list_L8
+
+  COR = cor_list_L4
+
+  IRR = irr_list_L5
+
+  VAR = var_list_L6
+
+
+  if (es_selected == "auto") {
+    if (measure %in% c("d", "g", "md")) {
+
+      if (selection_auto == "crude") {
+        res = c(USER_crude, SMD_post, SMD_paired, OR,
+                CONT, COR, PHI, SMD_adjusted,
+                USER_adjusted,
+                #not used
+                RR, IRR, VAR)
+
+      } else if (selection_auto == "adjusted") {
+        res = c(USER_adjusted, SMD_adjusted,
+                USER_crude, SMD_post,
+                SMD_paired, OR, CONT, COR,
+                PHI,
+                #not used
+                RR, IRR, VAR)
+      } else if (selection_auto == "paired") {
+        res = c(USER_crude, SMD_paired, SMD_post, SMD_adjusted,
+                USER_adjusted, OR, CONT, COR,
+                PHI,
+                #not used
+                RR, IRR, VAR)
+      } else {
+        stop("selection_auto should be one of 'crude', 'adjusted' or 'paired'")
+      }
+
+    } else if (measure %in% c("logor", "or")) {
+      res = c(USER_crude, OR, CONT, RR, PHI, COR, SMD_post, USER_adjusted,
+              #not used
+              SMD_paired, SMD_adjusted, IRR, VAR)
+
+    } else if (measure %in% c("logrr", "rr")) {
+      res = c(USER_crude, RR, CONT, OR, PHI, USER_adjusted,
+              #not used
+              SMD_post, SMD_paired,
+              COR, SMD_adjusted,
+              IRR, VAR)
+
+    } else if (measure %in% c("logirr", "irr")) {
+      res = c(USER_crude, IRR, USER_adjusted,
+              #not used
+              SMD_post, SMD_paired, OR,
+              CONT, COR, PHI, SMD_adjusted,
+              RR, VAR)
+
+    } else if (measure %in% c("nnt")) {
+      res = c(USER_crude, CONT, OR, RR, PHI, USER_adjusted,
+              #not used
+              SMD_post, SMD_paired, COR, SMD_adjusted,
+              IRR, VAR)
+
+    } else if (measure %in% c("r", "z")) {
+      res = c(USER_crude, COR, CONT, OR, PHI, SMD_post,
+              SMD_paired, USER_adjusted,
+              #not used
+              SMD_adjusted,
+              RR, IRR, VAR)
+
+    } else if (measure %in% c("logvr", "logcvr")) {
+      res = c(USER_crude, VAR, SMD_post, SMD_paired,USER_adjusted,
+              #not used
+              OR, CONT, COR, PHI, SMD_adjusted,
+              RR, IRR)
+
+    }
+  } else {
+    res = c(USER_crude, SMD_post, SMD_paired, OR,
+            CONT, COR, PHI, SMD_adjusted,
+            USER_adjusted,
+            #not used
+            RR, IRR, VAR)
+  }
+
+  df_sq_list = list(
+    es_odds_ratio_pval,  es_rr_pval, es_chisq, es_chisq_pval,
+    es_md_pval, es_anova_f,  es_anova_f_pval, es_r_point_bis_pval,
+    es_etasq, es_mean_change_pval, es_paired_t_pval, es_paired_f,
+    es_paired_f_pval, es_ancova_f, es_ancova_f_pval, es_etasq_adj, es_ancova_md_pval
+  )
+  warning_reverse = FALSE
+  for (i in seq_along(df_sq_list)) {
+    df <- df_sq_list[[i]]
+    ci_lo_cols <- grep("ci_lo", names(df), value = TRUE)
+
+    if (length(ci_lo_cols) > 0) {
+      for (col in ci_lo_cols) {
+        if (any(!is.na(df[[col]]))) {
+          warning_reverse = TRUE
+          break
+        }
+      }
+    }
+  }
+
+  if (warning_reverse & verbose) {
+    warning("When you enter input data that cannot be negative (F-test, eta-squared, p-value, or chi-square values), do not forget to properly set up the direction of the generated effect size using corresponding reverse_* argument!")
+  }
+  # print(length(res))
+  if (length(res) != 71) { stop ("failure to estimate all effect sizes (not expected, you trigerred a bug, please contact cgosling@parisnanterre.fr)") }
   class(res) <- "metaConvert"
   attr(res, "raw_data") <- x
   attr(res, "exp") <- exp
